(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    205741,       4122]*)
(*NotebookOutlinePosition[    206430,       4146]*)
(*  CellTagsIndexPosition[    206386,       4142]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["quickISObasis", "ObjectName"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  StyleBox["quickISObasis[", "MR"],
  StyleBox["ops", "TI"],
  StyleBox["]", "MR"],
  " generates an (I,S) basis, i.e. a basis with well defined total isospin I \
and total spin S quantum numbers."
}], "Usage"],

Cell[TextData[{
  "\[FilledSmallSquare] Operators ",
  StyleBox["ops", "IT"],
  " must be given in the stripped form without creation and spin index."
}], "Notes"],

Cell[TextData[{
  "\[FilledSmallSquare] Isospin phase may be defined using ",
  StyleBox["nnop", "MR"],
  ". See also ",
  ButtonBox["isospin",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes"],

Cell[TextData[{
  "\[FilledSmallSquare] See also: ",
  ButtonBox["qsbasis",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["qszbasis",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["transformtoIS",
    ButtonStyle->"AddOnsLink"],
  ", ",
  ButtonBox["isospin",
    ButtonStyle->"AddOnsLink"],
  "."
}], "Notes"],

Cell[CellGroupData[{

Cell["Further examples", "ExampleSection"],

Cell["Load sneg and declare some quantities", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< sneg`sneg`;\)\), "\[IndentingNewLine]", 
    \(\(snegfermionoperators[c];\)\)}], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \("sneg 1.168 Copyright (C) 2007 Rok Zitko"\)], "Print",
  CellLabel->"From In[1]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ClearAll[nnop];\)\), "\[IndentingNewLine]", 
    \(quickISObasis[{c[1]}] // MatrixForm\), "\[IndentingNewLine]", 
    \(quickISObasis[{c[1], c[2]}] // MatrixForm\), "\[IndentingNewLine]", 
    \(quickISObasis[{c[1], c[2], c[3]}] // MatrixForm\)}], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({1\/2, 0}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}], "}"}]},
            {\({0, 1\/2}\), 
              RowBox[{"{", 
                TagBox[
                  StyleBox[
                    InterpretationBox[
                      SubsuperscriptBox["c", 
                        RowBox[{"1", 
                          TagBox[
                            StyleBox["\<\"\[UpArrow]\"\>",
                              FontColor->RGBColor[1, 0, 0]],
                            (
                            StyleForm[ #, FontColor -> RGBColor[ 
                              1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                      Subsuperscript[ c, 
                        RowBox[ {1, 
                          StyleForm[ 
                          "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                        "\[Dagger]"],
                      Editable->False],
                    ScriptSizeMultipliers->1,
                    ScriptBaselineShifts->{1, 1}],
                  DisplayForm], "}"}]}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[4]//MatrixForm="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({1, 0}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}], "}"}]},
            {\({1\/2, 1\/2}\), 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}], ",", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}]}], "}"}]},
            {\({0, 1}\), 
              RowBox[{"{", 
                RowBox[{"\<\"-\"\>", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}]}], "}"}]},
            {\({0, 0}\), 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"-", 
                      FractionBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              InterpretationBox[
                                SubsuperscriptBox["c", 
                                  RowBox[{"1", 
                                    TagBox[
                                      StyleBox["\<\"\[DownArrow]\"\>",
                                        FontColor->RGBColor[0, 0, 1]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                                Subsuperscript[ c, 
                                  RowBox[ {1, 
                                    StyleForm[ 
                                    "\[DownArrow]", FontColor -> RGBColor[ 
                                      0, 0, 1]]}], "\[Dagger]"],
                                Editable->False],
                              ScriptSizeMultipliers->1,
                              ScriptBaselineShifts->{1, 1}],
                            DisplayForm], 
                          StyleBox["\[CenterDot]",
                            FontColor->RGBColor[0, 0.392187, 0]], 
                          TagBox[
                            StyleBox[
                              InterpretationBox[
                                SubsuperscriptBox["c", 
                                  RowBox[{"1", 
                                    TagBox[
                                      StyleBox["\<\"\[UpArrow]\"\>",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                                Subsuperscript[ c, 
                                  RowBox[ {1, 
                                    StyleForm[ 
                                    "\[UpArrow]", FontColor -> RGBColor[ 
                                      1, 0, 0]]}], "\[Dagger]"],
                                Editable->False],
                              ScriptSizeMultipliers->1,
                              ScriptBaselineShifts->{1, 1}],
                            DisplayForm]}], \(\@2\)]}], "+", 
                    FractionBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}], \(\@2\)]}], ",", 
                  RowBox[{
                    FractionBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}], \(\@2\)], "-", 
                    FractionBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}], \(\@2\)]}]}], "}"}]}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[5]//MatrixForm="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({3\/2, 0}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"3", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {3, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"3", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {3, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}], "}"}]},
            {\({1, 1\/2}\), 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"3", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {3, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"3", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {3, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}], ",", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"3", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {3, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"3", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {3, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}], ",", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"3", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {3, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}]}], "}"}]},
            {\({1\/2, 1}\), 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{"\<\"-\"\>", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"3", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {3, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"3", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {3, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}], ",", 
                  RowBox[{"\<\"-\"\>", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"3", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {3, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}], ",", 
                  RowBox[{"\<\"-\"\>", 
                    RowBox[{
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[DownArrow]\"\>",
                                    FontColor->RGBColor[0, 0, 1]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[DownArrow]", FontColor -> RGBColor[ 
                                  0, 0, 1]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"1", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {1, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"2", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {2, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm], 
                      StyleBox["\[CenterDot]",
                        FontColor->RGBColor[0, 0.392187, 0]], 
                      TagBox[
                        StyleBox[
                          InterpretationBox[
                            SubsuperscriptBox["c", 
                              RowBox[{"3", 
                                TagBox[
                                  StyleBox["\<\"\[UpArrow]\"\>",
                                    FontColor->RGBColor[1, 0, 0]],
                                  (
                                  StyleForm[ #, FontColor -> RGBColor[ 
                                    1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                            Subsuperscript[ c, 
                              RowBox[ {3, 
                                StyleForm[ 
                                "\[UpArrow]", FontColor -> RGBColor[ 
                                  1, 0, 0]]}], "\[Dagger]"],
                            Editable->False],
                          ScriptSizeMultipliers->1,
                          ScriptBaselineShifts->{1, 1}],
                        DisplayForm]}]}]}], "}"}]},
            {\({1\/2, 0}\), 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"-", 
                      FractionBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              InterpretationBox[
                                SubsuperscriptBox["c", 
                                  RowBox[{"1", 
                                    TagBox[
                                      StyleBox["\<\"\[DownArrow]\"\>",
                                        FontColor->RGBColor[0, 0, 1]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                                Subsuperscript[ c, 
                                  RowBox[ {1, 
                                    StyleForm[ 
                                    "\[DownArrow]", FontColor -> RGBColor[ 
                                      0, 0, 1]]}], "\[Dagger]"],
                                Editable->False],
                              ScriptSizeMultipliers->1,
                              ScriptBaselineShifts->{1, 1}],
                            DisplayForm], 
                          StyleBox["\[CenterDot]",
                            FontColor->RGBColor[0, 0.392187, 0]], 
                          TagBox[
                            StyleBox[
                              InterpretationBox[
                                SubsuperscriptBox["c", 
                                  RowBox[{"1", 
                                    TagBox[
                                      StyleBox["\<\"\[UpArrow]\"\>",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                                Subsuperscript[ c, 
                                  RowBox[ {1, 
                                    StyleForm[ 
                                    "\[UpArrow]", FontColor -> RGBColor[ 
                                      1, 0, 0]]}], "\[Dagger]"],
                                Editable->False],
                              ScriptSizeMultipliers->1,
                              ScriptBaselineShifts->{1, 1}],
                            DisplayForm], 
                          StyleBox["\[CenterDot]",
                            FontColor->RGBColor[0, 0.392187, 0]], 
                          TagBox[
                            StyleBox[
                              InterpretationBox[
                                SubsuperscriptBox["c", 
                                  RowBox[{"2", 
                                    TagBox[
                                      StyleBox["\<\"\[DownArrow]\"\>",
                                        FontColor->RGBColor[0, 0, 1]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                                Subsuperscript[ c, 
                                  RowBox[ {2, 
                                    StyleForm[ 
                                    "\[DownArrow]", FontColor -> RGBColor[ 
                                      0, 0, 1]]}], "\[Dagger]"],
                                Editable->False],
                              ScriptSizeMultipliers->1,
                              ScriptBaselineShifts->{1, 1}],
                            DisplayForm], 
                          StyleBox["\[CenterDot]",
                            FontColor->RGBColor[0, 0.392187, 0]], 
                          TagBox[
                            StyleBox[
                              InterpretationBox[
                                SubsuperscriptBox["c", 
                                  RowBox[{"2", 
                                    TagBox[
                                      StyleBox["\<\"\[UpArrow]\"\>",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                                Subsuperscript[ c, 
                                  RowBox[ {2, 
                                    StyleForm[ 
                                    "\[UpArrow]", FontColor -> RGBColor[ 
                                      1, 0, 0]]}], "\[Dagger]"],
                                Editable->False],
                              ScriptSizeMultipliers->1,
                              ScriptBaselineShifts->{1, 1}],
                            DisplayForm]}], \(\@6\)]}], "-", 
                    FractionBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"3", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {3, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"3", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {3, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}], \(\@6\)], "+", 
                    RowBox[{\(\@\(2\/3\)\), " ", 
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"3", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {3, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"3", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {3, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}]}]}], ",", 
                  RowBox[{
                    FractionBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"3", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {3, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"3", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {3, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}], \(\@2\)], "-", 
                    FractionBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"3", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {3, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"3", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {3, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}], \(\@2\)]}], ",", 
                  RowBox[{
                    RowBox[{"-", 
                      FractionBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              InterpretationBox[
                                SubsuperscriptBox["c", 
                                  RowBox[{"1", 
                                    TagBox[
                                      StyleBox["\<\"\[DownArrow]\"\>",
                                        FontColor->RGBColor[0, 0, 1]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                                Subsuperscript[ c, 
                                  RowBox[ {1, 
                                    StyleForm[ 
                                    "\[DownArrow]", FontColor -> RGBColor[ 
                                      0, 0, 1]]}], "\[Dagger]"],
                                Editable->False],
                              ScriptSizeMultipliers->1,
                              ScriptBaselineShifts->{1, 1}],
                            DisplayForm], 
                          StyleBox["\[CenterDot]",
                            FontColor->RGBColor[0, 0.392187, 0]], 
                          TagBox[
                            StyleBox[
                              InterpretationBox[
                                SubsuperscriptBox["c", 
                                  RowBox[{"1", 
                                    TagBox[
                                      StyleBox["\<\"\[UpArrow]\"\>",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                                Subsuperscript[ c, 
                                  RowBox[ {1, 
                                    StyleForm[ 
                                    "\[UpArrow]", FontColor -> RGBColor[ 
                                      1, 0, 0]]}], "\[Dagger]"],
                                Editable->False],
                              ScriptSizeMultipliers->1,
                              ScriptBaselineShifts->{1, 1}],
                            DisplayForm], 
                          StyleBox["\[CenterDot]",
                            FontColor->RGBColor[0, 0.392187, 0]], 
                          TagBox[
                            StyleBox[
                              InterpretationBox[
                                SubsuperscriptBox["c", 
                                  RowBox[{"2", 
                                    TagBox[
                                      StyleBox["\<\"\[DownArrow]\"\>",
                                        FontColor->RGBColor[0, 0, 1]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                                Subsuperscript[ c, 
                                  RowBox[ {2, 
                                    StyleForm[ 
                                    "\[DownArrow]", FontColor -> RGBColor[ 
                                      0, 0, 1]]}], "\[Dagger]"],
                                Editable->False],
                              ScriptSizeMultipliers->1,
                              ScriptBaselineShifts->{1, 1}],
                            DisplayForm], 
                          StyleBox["\[CenterDot]",
                            FontColor->RGBColor[0, 0.392187, 0]], 
                          TagBox[
                            StyleBox[
                              InterpretationBox[
                                SubsuperscriptBox["c", 
                                  RowBox[{"2", 
                                    TagBox[
                                      StyleBox["\<\"\[UpArrow]\"\>",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                                Subsuperscript[ c, 
                                  RowBox[ {2, 
                                    StyleForm[ 
                                    "\[UpArrow]", FontColor -> RGBColor[ 
                                      1, 0, 0]]}], "\[Dagger]"],
                                Editable->False],
                              ScriptSizeMultipliers->1,
                              ScriptBaselineShifts->{1, 1}],
                            DisplayForm]}], \(\@2\)]}], "+", 
                    FractionBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"3", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {3, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"3", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {3, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}], \(\@2\)]}], ",", 
                  RowBox[{
                    FractionBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"3", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {3, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}], \(\@2\)], "-", 
                    FractionBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"3", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {3, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}], \(\@2\)]}], ",", 
                  RowBox[{
                    FractionBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"3", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {3, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}], \(\@2\)], "-", 
                    FractionBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"3", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {3, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}], \(\@2\)]}]}], "}"}]},
            {\({0, 3\/2}\), 
              RowBox[{"{", 
                RowBox[{"\<\"-\"\>", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"3", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {3, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}]}], "}"}]},
            {\({0, 1\/2}\), 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"-", 
                      FractionBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              InterpretationBox[
                                SubsuperscriptBox["c", 
                                  RowBox[{"1", 
                                    TagBox[
                                      StyleBox["\<\"\[DownArrow]\"\>",
                                        FontColor->RGBColor[0, 0, 1]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                                Subsuperscript[ c, 
                                  RowBox[ {1, 
                                    StyleForm[ 
                                    "\[DownArrow]", FontColor -> RGBColor[ 
                                      0, 0, 1]]}], "\[Dagger]"],
                                Editable->False],
                              ScriptSizeMultipliers->1,
                              ScriptBaselineShifts->{1, 1}],
                            DisplayForm], 
                          StyleBox["\[CenterDot]",
                            FontColor->RGBColor[0, 0.392187, 0]], 
                          TagBox[
                            StyleBox[
                              InterpretationBox[
                                SubsuperscriptBox["c", 
                                  RowBox[{"1", 
                                    TagBox[
                                      StyleBox["\<\"\[UpArrow]\"\>",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                                Subsuperscript[ c, 
                                  RowBox[ {1, 
                                    StyleForm[ 
                                    "\[UpArrow]", FontColor -> RGBColor[ 
                                      1, 0, 0]]}], "\[Dagger]"],
                                Editable->False],
                              ScriptSizeMultipliers->1,
                              ScriptBaselineShifts->{1, 1}],
                            DisplayForm], 
                          StyleBox["\[CenterDot]",
                            FontColor->RGBColor[0, 0.392187, 0]], 
                          TagBox[
                            StyleBox[
                              InterpretationBox[
                                SubsuperscriptBox["c", 
                                  RowBox[{"2", 
                                    TagBox[
                                      StyleBox["\<\"\[UpArrow]\"\>",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (StyleForm[ #, FontColor -> RGBColor[ 
                                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                                Subsuperscript[ c, 
                                  RowBox[ {2, 
                                    StyleForm[ 
                                    "\[UpArrow]", FontColor -> RGBColor[ 
                                      1, 0, 0]]}], "\[Dagger]"],
                                Editable->False],
                              ScriptSizeMultipliers->1,
                              ScriptBaselineShifts->{1, 1}],
                            DisplayForm]}], \(\@2\)]}], "+", 
                    FractionBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"3", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {3, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"3", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {3, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}], \(\@2\)]}], ",", 
                  RowBox[{
                    RowBox[{"-", 
                      FractionBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              InterpretationBox[
                                SubsuperscriptBox["c", 
                                  RowBox[{"1", 
                                    TagBox[
                                      StyleBox["\<\"\[UpArrow]\"\>",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                                Subsuperscript[ c, 
                                  RowBox[ {1, 
                                    StyleForm[ 
                                    "\[UpArrow]", FontColor -> RGBColor[ 
                                      1, 0, 0]]}], "\[Dagger]"],
                                Editable->False],
                              ScriptSizeMultipliers->1,
                              ScriptBaselineShifts->{1, 1}],
                            DisplayForm], 
                          StyleBox["\[CenterDot]",
                            FontColor->RGBColor[0, 0.392187, 0]], 
                          TagBox[
                            StyleBox[
                              InterpretationBox[
                                SubsuperscriptBox["c", 
                                  RowBox[{"2", 
                                    TagBox[
                                      StyleBox["\<\"\[DownArrow]\"\>",
                                        FontColor->RGBColor[0, 0, 1]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                                Subsuperscript[ c, 
                                  RowBox[ {2, 
                                    StyleForm[ 
                                    "\[DownArrow]", FontColor -> RGBColor[ 
                                      0, 0, 1]]}], "\[Dagger]"],
                                Editable->False],
                              ScriptSizeMultipliers->1,
                              ScriptBaselineShifts->{1, 1}],
                            DisplayForm], 
                          StyleBox["\[CenterDot]",
                            FontColor->RGBColor[0, 0.392187, 0]], 
                          TagBox[
                            StyleBox[
                              InterpretationBox[
                                SubsuperscriptBox["c", 
                                  RowBox[{"2", 
                                    TagBox[
                                      StyleBox["\<\"\[UpArrow]\"\>",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                                Subsuperscript[ c, 
                                  RowBox[ {2, 
                                    StyleForm[ 
                                    "\[UpArrow]", FontColor -> RGBColor[ 
                                      1, 0, 0]]}], "\[Dagger]"],
                                Editable->False],
                              ScriptSizeMultipliers->1,
                              ScriptBaselineShifts->{1, 1}],
                            DisplayForm]}], \(\@2\)]}], "+", 
                    FractionBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"3", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {3, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"3", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {3, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}], \(\@2\)]}], ",", 
                  RowBox[{
                    RowBox[{"-", 
                      FractionBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              InterpretationBox[
                                SubsuperscriptBox["c", 
                                  RowBox[{"1", 
                                    TagBox[
                                      StyleBox["\<\"\[DownArrow]\"\>",
                                        FontColor->RGBColor[0, 0, 1]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                                Subsuperscript[ c, 
                                  RowBox[ {1, 
                                    StyleForm[ 
                                    "\[DownArrow]", FontColor -> RGBColor[ 
                                      0, 0, 1]]}], "\[Dagger]"],
                                Editable->False],
                              ScriptSizeMultipliers->1,
                              ScriptBaselineShifts->{1, 1}],
                            DisplayForm], 
                          StyleBox["\[CenterDot]",
                            FontColor->RGBColor[0, 0.392187, 0]], 
                          TagBox[
                            StyleBox[
                              InterpretationBox[
                                SubsuperscriptBox["c", 
                                  RowBox[{"1", 
                                    TagBox[
                                      StyleBox["\<\"\[UpArrow]\"\>",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                                Subsuperscript[ c, 
                                  RowBox[ {1, 
                                    StyleForm[ 
                                    "\[UpArrow]", FontColor -> RGBColor[ 
                                      1, 0, 0]]}], "\[Dagger]"],
                                Editable->False],
                              ScriptSizeMultipliers->1,
                              ScriptBaselineShifts->{1, 1}],
                            DisplayForm], 
                          StyleBox["\[CenterDot]",
                            FontColor->RGBColor[0, 0.392187, 0]], 
                          TagBox[
                            StyleBox[
                              InterpretationBox[
                                SubsuperscriptBox["c", 
                                  RowBox[{"3", 
                                    TagBox[
                                      StyleBox["\<\"\[UpArrow]\"\>",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                                Subsuperscript[ c, 
                                  RowBox[ {3, 
                                    StyleForm[ 
                                    "\[UpArrow]", FontColor -> RGBColor[ 
                                      1, 0, 0]]}], "\[Dagger]"],
                                Editable->False],
                              ScriptSizeMultipliers->1,
                              ScriptBaselineShifts->{1, 1}],
                            DisplayForm]}], \(\@2\)]}], "+", 
                    FractionBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"3", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {3, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}], \(\@2\)]}], ",", 
                  RowBox[{
                    FractionBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"3", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {3, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}], \(\@2\)], "-", 
                    FractionBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"3", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {3, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}], \(\@2\)]}], ",", 
                  RowBox[{
                    FractionBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"3", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {3, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}], \(\@6\)], "+", 
                    FractionBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"3", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {3, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}], \(\@6\)], "-", 
                    RowBox[{\(\@\(2\/3\)\), " ", 
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"3", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {3, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}]}]}]}], "}"}]}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[6]//MatrixForm="]
}, Open  ]],

Cell["\<\
Note the subtle difference in the sign of the first basis state in \
the (0,0) subspace.\
\>", "ExampleText"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(nnop[c[1]] = 1;\)\), "\[IndentingNewLine]", 
    \(\(nnop[c[2]] = 1;\)\), "\[IndentingNewLine]", 
    \(\(\(quickISObasis[{c[1], c[2]}] // MatrixForm\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(\(nnop[c[1]] = 1;\)\), "\n", 
    \(\(nnop[c[2]] = 0;\)\), "\n", 
    \(quickISObasis[{c[1], c[2]}] // MatrixForm\)}], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({1, 0}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}], "}"}]},
            {\({1\/2, 1\/2}\), 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}], ",", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}]}], "}"}]},
            {\({0, 1}\), 
              RowBox[{"{", 
                RowBox[{"\<\"-\"\>", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}]}], "}"}]},
            {\({0, 0}\), 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    RowBox[{"-", 
                      FractionBox[
                        RowBox[{
                          TagBox[
                            StyleBox[
                              InterpretationBox[
                                SubsuperscriptBox["c", 
                                  RowBox[{"1", 
                                    TagBox[
                                      StyleBox["\<\"\[DownArrow]\"\>",
                                        FontColor->RGBColor[0, 0, 1]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                                Subsuperscript[ c, 
                                  RowBox[ {1, 
                                    StyleForm[ 
                                    "\[DownArrow]", FontColor -> RGBColor[ 
                                      0, 0, 1]]}], "\[Dagger]"],
                                Editable->False],
                              ScriptSizeMultipliers->1,
                              ScriptBaselineShifts->{1, 1}],
                            DisplayForm], 
                          StyleBox["\[CenterDot]",
                            FontColor->RGBColor[0, 0.392187, 0]], 
                          TagBox[
                            StyleBox[
                              InterpretationBox[
                                SubsuperscriptBox["c", 
                                  RowBox[{"1", 
                                    TagBox[
                                      StyleBox["\<\"\[UpArrow]\"\>",
                                        FontColor->RGBColor[1, 0, 0]],
                                      (
                                      StyleForm[ #, FontColor -> RGBColor[ 
                                        1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                                Subsuperscript[ c, 
                                  RowBox[ {1, 
                                    StyleForm[ 
                                    "\[UpArrow]", FontColor -> RGBColor[ 
                                      1, 0, 0]]}], "\[Dagger]"],
                                Editable->False],
                              ScriptSizeMultipliers->1,
                              ScriptBaselineShifts->{1, 1}],
                            DisplayForm]}], \(\@2\)]}], "+", 
                    FractionBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}], \(\@2\)]}], ",", 
                  RowBox[{
                    FractionBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}], \(\@2\)], "-", 
                    FractionBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}], \(\@2\)]}]}], "}"}]}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[9]//MatrixForm="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\({1, 0}\), 
              RowBox[{"{", 
                RowBox[{
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"1", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {1, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[DownArrow]\"\>",
                                FontColor->RGBColor[0, 0, 1]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[DownArrow]", FontColor -> RGBColor[ 
                              0, 0, 1]]}], "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm], 
                  StyleBox["\[CenterDot]",
                    FontColor->RGBColor[0, 0.392187, 0]], 
                  TagBox[
                    StyleBox[
                      InterpretationBox[
                        SubsuperscriptBox["c", 
                          RowBox[{"2", 
                            TagBox[
                              StyleBox["\<\"\[UpArrow]\"\>",
                                FontColor->RGBColor[1, 0, 0]],
                              (
                              StyleForm[ #, FontColor -> RGBColor[ 
                                1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                        Subsuperscript[ c, 
                          RowBox[ {2, 
                            StyleForm[ 
                            "\[UpArrow]", FontColor -> RGBColor[ 1, 0, 0]]}], 
                          "\[Dagger]"],
                        Editable->False],
                      ScriptSizeMultipliers->1,
                      ScriptBaselineShifts->{1, 1}],
                    DisplayForm]}], "}"}]},
            {\({1\/2, 1\/2}\), 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}], ",", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[DownArrow]\"\>",
                                  FontColor->RGBColor[0, 0, 1]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[DownArrow]", FontColor -> RGBColor[ 
                                0, 0, 1]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}]}], "}"}]},
            {\({0, 1}\), 
              RowBox[{"{", 
                RowBox[{"\<\"-\"\>", 
                  RowBox[{
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"1", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {1, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm], 
                    StyleBox["\[CenterDot]",
                      FontColor->RGBColor[0, 0.392187, 0]], 
                    TagBox[
                      StyleBox[
                        InterpretationBox[
                          SubsuperscriptBox["c", 
                            RowBox[{"2", 
                              TagBox[
                                StyleBox["\<\"\[UpArrow]\"\>",
                                  FontColor->RGBColor[1, 0, 0]],
                                (
                                StyleForm[ #, FontColor -> RGBColor[ 
                                  1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                          Subsuperscript[ c, 
                            RowBox[ {2, 
                              StyleForm[ 
                              "\[UpArrow]", FontColor -> RGBColor[ 
                                1, 0, 0]]}], "\[Dagger]"],
                          Editable->False],
                        ScriptSizeMultipliers->1,
                        ScriptBaselineShifts->{1, 1}],
                      DisplayForm]}]}], "}"}]},
            {\({0, 0}\), 
              RowBox[{"{", 
                RowBox[{
                  RowBox[{
                    FractionBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}], \(\@2\)], "+", 
                    FractionBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}], \(\@2\)]}], ",", 
                  RowBox[{
                    FractionBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}], \(\@2\)], "-", 
                    FractionBox[
                      RowBox[{
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"1", 
                                  TagBox[
                                    StyleBox["\<\"\[UpArrow]\"\>",
                                      FontColor->RGBColor[1, 0, 0]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      1, 0, 0]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {1, 
                                  StyleForm[ 
                                  "\[UpArrow]", FontColor -> RGBColor[ 
                                    1, 0, 0]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm], 
                        StyleBox["\[CenterDot]",
                          FontColor->RGBColor[0, 0.392187, 0]], 
                        TagBox[
                          StyleBox[
                            InterpretationBox[
                              SubsuperscriptBox["c", 
                                RowBox[{"2", 
                                  TagBox[
                                    StyleBox["\<\"\[DownArrow]\"\>",
                                      FontColor->RGBColor[0, 0, 1]],
                                    (
                                    StyleForm[ #, FontColor -> RGBColor[ 
                                      0, 0, 1]]&)]}], "\<\"\[Dagger]\"\>"],
                              Subsuperscript[ c, 
                                RowBox[ {2, 
                                  StyleForm[ 
                                  "\[DownArrow]", FontColor -> RGBColor[ 
                                    0, 0, 1]]}], "\[Dagger]"],
                              Editable->False],
                            ScriptSizeMultipliers->1,
                            ScriptBaselineShifts->{1, 1}],
                          DisplayForm]}], \(\@2\)]}]}], "}"}]}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[12]//MatrixForm="]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 2880}, {0, 1200}},
WindowSize->{646, 600},
WindowMargins->{{Automatic, 102}, {Automatic, 0}},
ShowSelection->True,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 35, 0, 38, "ObjectName"],
Cell[1814, 55, 253, 7, 48, "Usage"],
Cell[2070, 64, 163, 4, 24, "Notes"],
Cell[2236, 70, 194, 7, 24, "Notes"],
Cell[2433, 79, 322, 14, 24, "Notes"],

Cell[CellGroupData[{
Cell[2780, 97, 42, 0, 38, "ExampleSection"],
Cell[2825, 99, 60, 0, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[2910, 103, 139, 3, 42, "Input"],
Cell[3052, 108, 103, 2, 21, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3192, 115, 303, 5, 74, "Input"],
Cell[3498, 122, 3336, 76, 74, "Output"],
Cell[6837, 200, 22609, 458, 138, "Output"],
Cell[29449, 660, 130566, 2519, 216, "Output"]
}, Open  ]],
Cell[160030, 3182, 119, 3, 34, "ExampleText"],

Cell[CellGroupData[{
Cell[160174, 3189, 389, 8, 122, "Input"],
Cell[160566, 3199, 22609, 458, 138, "Output"],
Cell[183178, 3659, 22523, 458, 138, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

